# Insert your code here


class Operations:
    def __init__(self):
        self.name = "Basic Calculator Example"

    def add(self, x, y):
        return x + y

    def divide(self, x, y):
        pass

    def multiply(self, x, y):
        pass
